# PINGSeg
[![PyPI - Version](https://img.shields.io/pypi/v/pingseg?style=flat-square&label=Latest%20Version%20(PyPi))](https://pypi.org/project/pingseg/)

Utility to perform semantic segmentation on sonar imagery.

**UNDER CONSTRUCTION**

Check back soon....

# Installation


# Acknowledgements
This would not have been possible without the fantastic work of [Dr. Daniel Buscombe](https://github.com/dbuscombe-usgs) and [Dr. Evan Goldstein](https://github.com/ebgoldstein) and as implemented in [Segmentation Gym](https://github.com/Doodleverse/segmentation_gym).